summaryrefslogtreecommitdiff
path: root/src/misc_gui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/misc_gui.cpp')
-rw-r--r--src/misc_gui.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/misc_gui.cpp b/src/misc_gui.cpp
index 59b0282d5..6ba65c703 100644
--- a/src/misc_gui.cpp
+++ b/src/misc_gui.cpp
@@ -399,7 +399,7 @@ public:
*/
void ShowLandInfo(TileIndex tile)
{
- DeleteWindowById(WC_LAND_INFO, 0);
+ CloseWindowById(WC_LAND_INFO, 0);
new LandInfoWindow(tile);
}
@@ -564,7 +564,7 @@ struct AboutWindow : public Window {
void ShowAboutWindow()
{
- DeleteWindowByClass(WC_GAME_OPTIONS);
+ CloseWindowByClass(WC_GAME_OPTIONS);
new AboutWindow();
}
@@ -789,7 +789,7 @@ struct TooltipsWindow : public Window
*/
void GuiShowTooltips(Window *parent, StringID str, uint paramcount, const uint64 params[], TooltipCloseCondition close_tooltip)
{
- DeleteWindowById(WC_TOOLTIPS, 0);
+ CloseWindowById(WC_TOOLTIPS, 0);
if (str == STR_NULL || !_cursor.in_window) return;
@@ -1142,7 +1142,7 @@ void ShowQueryString(StringID str, StringID caption, uint maxsize, Window *paren
{
assert(parent != nullptr);
- DeleteWindowByClass(WC_QUERY_STRING);
+ CloseWindowByClass(WC_QUERY_STRING);
new QueryStringWindow(str, caption, ((flags & QSF_LEN_IN_CHARS) ? MAX_CHAR_LENGTH : 1) * maxsize, maxsize, &_query_string_desc, parent, afilter, flags);
}
@@ -1219,7 +1219,7 @@ struct QueryWindow : public Window {
switch (widget) {
case WID_Q_YES: {
/* in the Generate New World window, clicking 'Yes' causes
* DeleteNonVitalWindows() to be called - we shouldn't be in a window then */
QueryCallbackProc *proc = this->proc;
Window *parent = this->parent;
/* Prevent the destructor calling the callback function */
@@ -1219,7 +1219,7 @@ struct QueryWindow : public Window {
case WID_Q_YES: {
/* in the Generate New World window, clicking 'Yes' causes
- * DeleteNonVitalWindows() to be called - we shouldn't be in a window then */
+ * CloseNonVitalWindows() to be called - we shouldn't be in a window then */
QueryCallbackProc *proc = this->proc;
Window *parent = this->parent;